@@ -336,7 +336,7 @@ class JulepChildSocketServer(object):
 
 	def exit(self,status):
 		self.logger.info("Process %d is shutting down."%self.pid)
-		self.sb_struct.update(status = scoreboard.Status.DEAD)
+		self.sb_struct.update(status = scoreboard.Status.DYING)
 		self.sb_struct.flush()
 
 		self.write_pipe.close()
